@@ -30,7 +30,8 @@ def shorten_path(path):
     # and the way Python displays filenames may vary.
     # To properly compare, we convert everything to lowercase
     # However, we ensure that the shortened path retains its cases
-    ext = os.path.splitext(path)
+    ext = os.path.splitext(path)[1]
+
     path_lower = path.lower()
     path_lower = os.path.splitext(path_lower)[0]
 
